polysig_
node_
bindings
0.8.0
Module meeting
Module Items
Functions
In polysig_
node_
bindings::
protocols
polysig_node_bindings
::
protocols
Module
meeting
Bindings for meeting points.
Functions

create_
meeting
Create a meeting point used to exchange public keys.
join_
meeting
Join a meeting point used to exchange public keys.